import { newVarInputVal } from "js/composer/varInputValManager";

export const dataCommands = {
  label: "数据处理",
  icon: "format_color_text",
  defaultOpened: false,
  commands: [
    {
      value: "quickcomposer.data.reverseString",
      label: "字符串反转",
      config: [
        {
          key: "text",
          label: "要反转的文本",
          component: "VariableInput",
          icon: "swap_horiz",
        },
      ],
      outputVariable: "reversedText",
      saveOutput: true,
    },
    {
      value: "quickcomposer.data.replaceString",
      label: "字符串替换",
      config: [
        {
          key: "text",
          label: "原始文本",
          component: "VariableInput",
          icon: "text_fields",
          width: 4,
        },
        {
          key: "oldStr",
          label: "要替换的文本",
          component: "VariableInput",
          icon: "find_replace",
          width: 4,
        },
        {
          key: "newStr",
          label: "替换为",
          component: "VariableInput",
          icon: "text_fields",
          width: 4,
        },
      ],
      outputVariable: "replacedText",
      saveOutput: true,
    },
    {
      value: "quickcomposer.data.substring",
      label: "字符串截取",
      config: [
        {
          key: "text",
          label: "原始文本",
          component: "VariableInput",
          icon: "text_fields",
          width: 6,
        },
        {
          key: "start",
          label: "起始位置",
          component: "NumberInput",
          min: 0,
          step: 1,
          icon: "first_page",
          width: 3,
        },
        {
          key: "end",
          label: "结束位置",
          component: "NumberInput",
          icon: "last_page",
          min: 0,
          step: 1,
          width: 3,
        },
      ],
      outputVariable: "substringText",
      saveOutput: true,
    },
    {
      value: "quickcomposer.data.regexTransform",
      label: "正则提取/替换",
      component: "RegexEditor",
      componentProps: {
        inputLabel: "要处理的文本",
      },
      outputVariable: "processedText",
      saveOutput: true,
    },
    {
      value: "quickcomposer.data.buffer.from",
      label: "Buffer操作",
      desc: "Buffer创建、转换和操作",
      config: [],
      icon: "memory",
      subCommands: [
        {
          value: "quickcomposer.data.buffer.from",
          label: "创建Buffer",
          icon: "add_box",
          config: [
            {
              label: "数据",
              component: "VariableInput",
              icon: "text_fields",
              width: 9,
            },
            {
              label: "编码",
              component: "q-select",
              icon: "code",
              options: [
                { label: "UTF-8", value: "utf8" },
                { label: "UTF-16LE", value: "utf16le" },
                { label: "Latin1", value: "latin1" },
                { label: "Base64", value: "base64" },
                { label: "Hex", value: "hex" },
                { label: "ASCII", value: "ascii" },
                { label: "Binary", value: "binary" },
                { label: "UCS-2", value: "ucs2" },
              ],
              defaultValue: "utf8",
              width: 3,
            },
          ],
        },
        {
          value: "quickcomposer.data.buffer.toString",
          label: "转换字符串",
          icon: "text_fields",
          config: [
            {
              label: "Buffer",
              component: "VariableInput",
              icon: "memory",
              width: 12,
            },
            {
              label: "编码",
              component: "q-select",
              icon: "code",
              options: [
                { label: "UTF-8", value: "utf8" },
                { label: "UTF-16LE", value: "utf16le" },
                { label: "Latin1", value: "latin1" },
                { label: "Base64", value: "base64" },
                { label: "Hex", value: "hex" },
                { label: "ASCII", value: "ascii" },
                { label: "Binary", value: "binary" },
                { label: "UCS-2", value: "ucs2" },
              ],
              defaultValue: "utf8",
              width: 4,
            },
            {
              label: "起始位置",
              component: "NumberInput",
              step: 1,
              icon: "first_page",
              width: 4,
            },
            {
              label: "结束位置",
              component: "NumberInput",
              icon: "last_page",
              step: 1,
              width: 4,
            },
          ],
        },
        {
          value: "quickcomposer.data.buffer.write",
          label: "写入数据",
          icon: "edit",
          config: [
            {
              label: "Buffer",
              component: "VariableInput",
              icon: "memory",
              width: 6,
            },
            {
              label: "要写入的字符串",
              component: "VariableInput",
              icon: "edit",
              width: 6,
            },
            {
              label: "偏移量",
              component: "NumberInput",
              icon: "first_page",
              width: 4,
            },
            {
              label: "长度",
              component: "NumberInput",
              icon: "straighten",
              width: 4,
            },
            {
              label: "编码",
              component: "q-select",
              icon: "code",
              options: [
                { label: "UTF-8", value: "utf8" },
                { label: "UTF-16LE", value: "utf16le" },
                { label: "Latin1", value: "latin1" },
                { label: "Base64", value: "base64" },
                { label: "Hex", value: "hex" },
                { label: "ASCII", value: "ascii" },
                { label: "Binary", value: "binary" },
                { label: "UCS-2", value: "ucs2" },
              ],
              defaultValue: "utf8",
              width: 4,
            },
          ],
        },
        {
          value: "quickcomposer.data.buffer.fill",
          label: "填充数据",
          icon: "format_color_fill",
          config: [
            {
              label: "Buffer",
              component: "VariableInput",
              icon: "memory",
              width: 6,
            },
            {
              label: "填充值",
              component: "VariableInput",
              icon: "format_color_fill",
              width: 6,
            },
            {
              label: "起始位置",
              component: "NumberInput",
              icon: "first_page",
              width: 4,
            },
            {
              label: "结束位置",
              component: "NumberInput",
              icon: "last_page",
              width: 4,
            },
            {
              label: "编码",
              component: "q-select",
              icon: "code",
              options: [
                { label: "UTF-8", value: "utf8" },
                { label: "UTF-16LE", value: "utf16le" },
                { label: "Latin1", value: "latin1" },
                { label: "Base64", value: "base64" },
                { label: "Hex", value: "hex" },
                { label: "ASCII", value: "ascii" },
                { label: "Binary", value: "binary" },
                { label: "UCS-2", value: "ucs2" },
              ],
              defaultValue: "utf8",
              width: 4,
            },
          ],
        },
        {
          value: "quickcomposer.data.buffer.copy",
          label: "复制数据",
          icon: "content_copy",
          config: [
            {
              label: "源Buffer",
              component: "VariableInput",
              icon: "content_copy",
              width: 6,
            },
            {
              label: "目标Buffer",
              component: "VariableInput",
              icon: "save",
              width: 6,
            },
            {
              label: "目标起始位置",
              component: "NumberInput",
              icon: "first_page",
              width: 4,
            },
            {
              label: "源起始位置",
              component: "NumberInput",
              icon: "first_page",
              width: 4,
            },
            {
              label: "源结束位置",
              component: "NumberInput",
              icon: "last_page",
              width: 4,
            },
          ],
        },
        {
          value: "quickcomposer.data.buffer.compare",
          label: "比较数据",
          icon: "compare",
          config: [
            {
              label: "Buffer 1",
              component: "VariableInput",
              icon: "memory",
              width: 6,
            },
            {
              label: "Buffer 2",
              component: "VariableInput",
              icon: "memory",
              width: 6,
            },
          ],
        },
        {
          value: "quickcomposer.data.buffer.concat",
          label: "连接Buffer",
          icon: "merge",
          config: [
            {
              label: "Buffer",
              component: "ArrayEditor",
              icon: "memory",
              width: 12,
              defaultValue: [newVarInputVal("var")],
              disableToggleType: true,
            },
            {
              label: "总长度（可选）",
              component: "NumberInput",
              icon: "straighten",
              width: 12,
            },
          ],
        },
        {
          value: "quickcomposer.data.buffer.slice",
          label: "切片数据",
          icon: "content_cut",
          config: [
            {
              label: "Buffer",
              component: "VariableInput",
              icon: "memory",
              width: 12,
            },
            {
              label: "起始位置",
              component: "NumberInput",
              icon: "first_page",
              width: 6,
            },
            {
              label: "结束位置",
              component: "NumberInput",
              icon: "last_page",
              width: 6,
            },
          ],
        },
        {
          value: "quickcomposer.data.buffer.indexOf",
          label: "查找数据",
          icon: "search",
          config: [
            {
              label: "Buffer",
              component: "VariableInput",
              icon: "memory",
              width: 12,
            },
            {
              label: "要查找的值",
              component: "VariableInput",
              icon: "search",
              width: 4,
            },
            {
              label: "起始位置",
              component: "NumberInput",
              icon: "first_page",
              width: 4,
            },
            {
              label: "编码",
              component: "q-select",
              icon: "code",
              options: [
                { label: "UTF-8", value: "utf8" },
                { label: "UTF-16LE", value: "utf16le" },
                { label: "Latin1", value: "latin1" },
                { label: "Base64", value: "base64" },
                { label: "Hex", value: "hex" },
                { label: "ASCII", value: "ascii" },
                { label: "Binary", value: "binary" },
                { label: "UCS-2", value: "ucs2" },
              ],
              defaultValue: "utf8",
              width: 4,
            },
          ],
        },
        {
          value: "quickcomposer.data.buffer.swap",
          label: "交换字节序",
          icon: "swap_horiz",
          config: [
            {
              label: "Buffer",
              component: "VariableInput",
              icon: "memory",
              width: 9,
            },
            {
              label: "字节大小",
              component: "q-select",
              icon: "memory",
              options: [
                { label: "16位", value: 16 },
                { label: "32位", value: 32 },
                { label: "64位", value: 64 },
              ],
              defaultValue: 16,
              width: 3,
            },
          ],
        },
      ],
    },
    {
      value: "quickcomposer.data.zlib",
      label: "数据压缩解压",
      desc: "使用 zlib 进行数据压缩和解压",
      component: "ZlibEditor",
      icon: "compress",
      isAsync: true,
    },
    {
      value: "quickcomposer.data.htmlParser",
      label: "HTML解析",
      desc: "解析 HTML 字符串",
      icon: "html",
      config: [
        {
          label: "要解析的 HTML",
          component: "VariableInput",
          icon: "html",
          placeholder: "例如：<div>Hello, World!</div>",
          width: 12,
        },
        {
          label: "CSS选择器",
          component: "VariableInput",
          icon: "css",
          placeholder: "例如：.class",
          width: 7,
        },
        {
          label: "属性",
          component: "VariableInput",
          icon: "colorize",
          options: {
            items: [
              { label: "innerText", value: "innerText" },
              { label: "innerHTML", value: "innerHTML" },
              { label: "href", value: "href" },
              { label: "src", value: "src" },
              { label: "value", value: "value" },
            ],
          },
          defaultValue: newVarInputVal("str"),
          width: 5,
        },
      ],
    },
  ],
};
